from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, String

Gmvalue_Scaf_V0_1_0 = CommandToolBuilder(tool="gmvalue_scaf", base_command=["gmvalue", "scaf"], inputs=[ToolInput(tag="in_input_scaffold_fasta", input_type=File(optional=True), prefix="--query", doc=InputDocumentation(doc="input scaffold fasta file (e.g., scaf1.fa)")), ToolInput(tag="in_ref", input_type=File(optional=True), prefix="--ref", doc=InputDocumentation(doc="input reference file (e.g., ref.fa)")), ToolInput(tag="in_min_id", input_type=Int(optional=True), prefix="--min_id", doc=InputDocumentation(doc="minimum alignment identity (%) [default: 97]")), ToolInput(tag="in_min_cov", input_type=Int(optional=True), prefix="--min_cov", doc=InputDocumentation(doc="minimum coverage (%) of query (contig) aligned to a reference [default: 99]")), ToolInput(tag="in_min_align", input_type=Int(optional=True), prefix="--min_align", doc=InputDocumentation(doc="minimum alignment overlap length with the maximum allowable size of indels [default: 200]")), ToolInput(tag="in_min_len", input_type=Int(optional=True), prefix="--min_len", doc=InputDocumentation(doc="minimum contig length to be considered [default: 200]")), ToolInput(tag="in_prefix_name_output", input_type=String(optional=True), prefix="--prefix", doc=InputDocumentation(doc="prefix name of output files")), ToolInput(tag="in_error_correct", input_type=String(optional=True), prefix="--error_correct", doc=InputDocumentation(doc="output an error-corrected contig set [default: false]")), ToolInput(tag="in_nuc_len", input_type=Int(optional=True), prefix="--nuc_len", doc=InputDocumentation(doc="minimum exact match length for specifying nucmer option -l [default: 30]")), ToolInput(tag="in_min_gap", input_type=Int(optional=True), prefix="--min_gap", doc=InputDocumentation(doc="minimum gap size in query scaffolds to split into subcontigs [default: 1]")), ToolInput(tag="in_max_gap", input_type=Int(optional=True), prefix="--max_gap", doc=InputDocumentation(doc="maximum length of gaps contained in the scaffolds [default: 50000]")), ToolInput(tag="in_max_in_del", input_type=Int(optional=True), prefix="--max_indel", doc=InputDocumentation(doc="maximum allowable size of indels in subcontigs (or distance between break points of a local misassembly) [default: 100]")), ToolInput(tag="in_thread", input_type=Int(optional=True), prefix="--thread", doc=InputDocumentation(doc="number of threads to run [default: 1]")), ToolInput(tag="in_var_13", input_type=String(optional=True), prefix="--help", doc=InputDocumentation(doc="")), ToolInput(tag="in_gm_value", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_usage", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_input", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_minimum", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_number", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_19", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_alignment", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_an", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_contig", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_coverage", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_exact", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_gap", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_26", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_name", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_reference", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_scaffold", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_verdot", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_error_corrected", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_fast_a", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_identity", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_match", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_overlap", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_threads", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_file", input_type=File(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_gaps", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_in", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_length", input_type=Int(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_output", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_to", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_be", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_contained", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_for", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_46", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_run", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_set", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_with", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_considered", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_scaffolds", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_specifying", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_the", input_type=String(), position=5, doc=InputDocumentation(doc="")), ToolInput(tag="in_maximum", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_nuc_mer", input_type=String(), position=6, doc=InputDocumentation(doc="")), ToolInput(tag="in_allowable", input_type=String(), position=7, doc=InputDocumentation(doc="")), ToolInput(tag="in_split", input_type=String(), position=7, doc=InputDocumentation(doc="")), ToolInput(tag="in_into", input_type=String(), position=8, doc=InputDocumentation(doc="")), ToolInput(tag="in_size", input_type=Int(), position=8, doc=InputDocumentation(doc="")), ToolInput(tag="in_of", input_type=String(), position=9, doc=InputDocumentation(doc="")), ToolInput(tag="in_sub_contigs", input_type=String(), position=9, doc=InputDocumentation(doc="")), ToolInput(tag="in_indels", input_type=String(), position=10, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gmvalue_Scaf_V0_1_0().translate("wdl", allow_empty_container=True)

